package com.yunzhi.marketing.xlk.controller;

import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.core.metadata.IPage;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.yunzhi.marketing.base.BaseController;
import com.yunzhi.marketing.base.ResponseBean;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RequestMethod;
import org.springframework.web.bind.annotation.RequestParam;
import org.springframework.web.bind.annotation.ResponseBody;
import com.yunzhi.marketing.xlk.service.IBrandService;
import com.yunzhi.marketing.xlk.entity.Brand;
import org.springframework.web.bind.annotation.RestController;

/**
 * <p>
    * 品牌开发商表  前端控制器
    * </p>
 *
 * @author jobob
 * @since 2021-05-13
 */
@RestController
@RequestMapping("/")
public class BrandController extends BaseController {

    private final Logger logger = LoggerFactory.getLogger(BrandController.class);

    @Autowired
    public IBrandService iBrandService;


    /**
     * 分页查询列表
     * @param pageNum
     * @param pageSize
     * @return
     */
    @RequestMapping(value="/brand",method= RequestMethod.GET)
    public ResponseBean brandList(@RequestParam(value ="pageNum",defaultValue = "1") Integer pageNum,
                                  @RequestParam(value ="pageSize",defaultValue = "10") Integer pageSize){
        ResponseBean responseBean = new ResponseBean();
        try {
            //使用分页插件
		    IPage<Brand> pg = new Page<>(pageNum, pageSize);
            QueryWrapper<Brand> queryWrapper = new QueryWrapper<>();
            queryWrapper.orderByDesc("create_date");

            IPage<Brand> result = iBrandService.page(pg, queryWrapper);
            responseBean.addSuccess(result);
        }catch (Exception e){
            e.printStackTrace();
            logger.error("brandList -=- {}",e.toString());
            responseBean.addError(e.getMessage());
        }
        return responseBean;
    }

    /**
     * 保存对象
     * @param brand 实体对象
     * @return
     */
    @RequestMapping(value="/brand",method= RequestMethod.POST)
    public ResponseBean brandAdd(@RequestBody Brand brand){
        ResponseBean responseBean = new ResponseBean();
        try {
            if (iBrandService.save(brand)){
                responseBean.addSuccess(brand);
            }else {
                responseBean.addError("fail");
            }
        }catch (Exception e){
            e.printStackTrace();
            logger.error("brandAdd -=- {}",e.toString());
            responseBean.addError(e.getMessage());
        }
        return responseBean;
    }

    /**
     * 根据id删除对象
     * @param id  实体ID
     */
    @ResponseBody
    @RequestMapping(value="/brand/{id}", method= RequestMethod.DELETE)
    public ResponseBean brandDelete(@PathVariable Integer id){
        ResponseBean responseBean = new ResponseBean();
        try {
            if(iBrandService.removeById(id)){
                responseBean.addSuccess("success");
            }else {
                responseBean.addError("fail");
            }
        }catch (Exception e){
            e.printStackTrace();
            logger.error("brandDelete -=- {}",e.toString());
            responseBean.addError(e.getMessage());
        }
        return responseBean;
    }

    /**
     * 修改对象
     * @param id  实体ID
     * @param brand 实体对象
     * @return
     */
    @RequestMapping(value="/brand/{id}",method= RequestMethod.PUT)
    public ResponseBean brandUpdate(@PathVariable Integer id,
                                        @RequestBody Brand brand){
        ResponseBean responseBean = new ResponseBean();
        try {
            if (iBrandService.updateById(brand)){
                responseBean.addSuccess(brand);
            }else {
                responseBean.addError("fail");
            }
        }catch (Exception e){
            e.printStackTrace();
            logger.error("brandUpdate -=- {}",e.toString());
            responseBean.addError(e.getMessage());
        }
        return responseBean;
    }

    /**
     * 根据id查询对象
     * @param id  实体ID
     */
    @RequestMapping(value="/brand/{id}",method= RequestMethod.GET)
    public ResponseBean brandGet(@PathVariable Integer id){
        ResponseBean responseBean = new ResponseBean();
        try {
            responseBean.addSuccess(iBrandService.getById(id));
        }catch (Exception e){
            e.printStackTrace();
            logger.error("brandDelete -=- {}",e.toString());
            responseBean.addError(e.getMessage());
        }
        return responseBean;
    }
}
